@@ -19,26 +19,32 @@ class User:
                          params={'detail': True})
         if r.status_code != 200:
             raise RuntimeError('incorrect result from \'user/list\' service: %s' % r.text)
-        result = r.json()
+        response = r.json()
         if not self.is_json:
-            res = PrettyTable(["ID", "TID", "Name", "Email", "Roles", "Groups"])
-            res.align["Name"] = "l"
-            for r in result:
-                roles = []
-                for role in r["roles"]:
-                    if "entity_code" in role:
-                        roles.append("%s:%s" % (role["entity_code"], role["name"]))
-                    else:
-                        roles.append(role["name"])
-                groups = []
-                for group in r["groups"]:
-                    name = r["entity_code"] + ":" + group["name"]
-                    groups.append(name)
-                res.add_row([r["id"], r["tid"], r["name"], r["email"], " ".join(roles),
-                             " ".join(groups)])
+            result = PrettyTable(["ID", "TID", "Name", "Email", "Roles", "Groups"])
+            result.align["Name"] = "l"
+            for item in response:
+                result = self.update_result(result, item)
         else:
-            res = result
-        return res
+            result = response
+        return result
+
+    @staticmethod
+    def update_result(result, item):
+        roles = []
+        for role in item["roles"]:
+            if "entity_code" in role:
+                roles.append("%s:%s" % (role["entity_code"], role["name"]))
+            else:
+                roles.append(role["name"])
+        groups = []
+        for group in item["groups"]:
+            name = item["entity_code"] + ":" + group["name"]
+            groups.append(name)
+        result.add_row([item["id"], item["tid"], item["name"], item["email"],
+                       " ".join(roles), " ".join(groups)])
+
+        return result
 
     def add(self):
         if not re.match(r"^[A-Z]{3}$", self.options.user_code):
@@ -86,7 +92,7 @@ class User:
                               auth=self.auth, json=data)
             if r.status_code != 200:
                 raise RuntimeError('incorrect result from \'user/modify\' service: %s' % r.text)
-        res = "ok new user: email=%s -> id=%d" % (self.options.email, r.json())
+        res = "ok new user: email=%s -> id=%d" % (self.options.email, user_id)
         return res
 
     def modify(self):
@@ -144,25 +150,12 @@ class User:
         response = r.json()
 
         if not self.is_json:
-            res = PrettyTable(["ID", "TID", "Name", "Email", "Roles", "Groups"])
-            res.align["Name"] = "l"
-
-            roles = []
-
-            for role in response["roles"]:
-                if "entity_code" in role:
-                    roles.append("%s:%s" % (role["entity_code"], role["name"]))
-                else:
-                    roles.append(role["name"])
-            groups = []
-            for group in response["groups"]:
-                name = response["entity_code"] + ":" + group["name"]
-                groups.append(name)
-            res.add_row([response["id"], response["tid"], response["name"], response["email"],
-                         " ".join(roles), " ".join(groups)])
+            result = PrettyTable(["ID", "TID", "Name", "Email", "Roles", "Groups"])
+            result.align["Name"] = "l"
+            result = self.update_result(result, response)
         else:
-            res = response
-        return res
+            result = response
+        return result
 
     def password(self):
         data = {
