@@ -69,7 +69,7 @@ def define_option():
     launcher.shortcut_map["lm"] = ["model", "list"]
     parser_list_models.add_argument('-s', '--source', help='source language prefix')
     parser_list_models.add_argument('-t', '--target', help='target language prefix')
-    parser_list_models.add_argument('-m', '--model', nargs='*', help='beginning pattern on model name')
+    parser_list_models.add_argument('-m', '--model', nargs='*', help='pattern search by regex')
     parser_list_models.add_argument('--tags', nargs="*", help='model tags')
     parser_list_models.add_argument('--skip_noscores', action='store_true',
                                     help='skip models without scores')
@@ -81,6 +81,8 @@ def define_option():
                                     help='only display matching model ids')
     parser_list_models.add_argument('--show_owner', '-so', action='store_true',
                                     help='display model owner')
+    parser_list_models.add_argument('--show_domain', '-sd', action='store_true',
+                                    help='display model domain')
     parser_list_models.add_argument('--count', action='store_true',
                                     help='only display count of models')
     parser_list_models.add_argument('--aggr', choices=['lp', 'model'],
@@ -218,7 +220,33 @@ def define_option():
                                                                       'given storage')
     launcher.shortcut_map["gr"] = ["resource", "get"]
     parser_get_resources.add_argument('-s', '--service', help="service name")
-    parser_get_resources.add_argument('--path', help='path to the file', required=True)
+    parser_get_resources.add_argument('--paths', nargs='*', help='path to the files', required=True)
+    parser_get_resources.add_argument('--format', help='file format (txt, tmx, json, tsv, json-edition)')
+    parser_get_resources.add_argument('--output_dir', help='output directory of the downloaded files')
+
+    parser_add_resources = subparsers_resource.add_parser('upload', help='{ur} upload files to '
+                                                                         'given storage')
+    launcher.shortcut_map["ur"] = ["resource", "upload"]
+    parser_add_resources.add_argument('-s', '--service', help="service name")
+    parser_add_resources.add_argument('--files', nargs='*', help='path to the local files',
+                                      required=True)
+    parser_add_resources.add_argument('--storage_path', help='path to the remote storage', required=True)
+
+    parser_add_resources = subparsers_resource.add_parser('edit', help='{er} edit files in a '
+                                                                         'given storage')
+    launcher.shortcut_map["er"] = ["resource", "edit"]
+    parser_add_resources.add_argument('-s', '--service', help="service name")
+    parser_add_resources.add_argument('--path', help='path to the local file',
+                                      required=False)
+    parser_add_resources.add_argument('--storage_path', help='path to the remote storage', required=True)
+    parser_add_resources.add_argument('--properties', action='store_true', help='Edit properties instead of file')
+    parser_add_resources.add_argument('--filename', help='New filename')
+    parser_add_resources.add_argument('--license', help='License of the corpus')
+    parser_add_resources.add_argument('--publisher', help='Publisher of the corpus')
+    parser_add_resources.add_argument('--source', help='Source of the corpus')
+    parser_add_resources.add_argument('--domain', help='Domain of the corpus')
+    parser_add_resources.add_argument('--genre', help='Genre of the corpus')
+    parser_add_resources.add_argument('--notes', help='Any notes on the corpus (as a json string)')
 
     subparsers_user = launcher.subparsers_map["user"].add_subparsers(help='sub-command help',
                                                                      dest='subcmd')
@@ -301,6 +329,9 @@ def define_option():
                                         help='choice to upgrade when later docker image available:'
                                              ' `auto`(interactive), `none`, `force`')
 
+    launcher.parser_exec.add_argument('--not_patch_envvar', action='store_true',
+                                      help='do not auto patch storage environment variables')
+
     parser_config_service = launcher.subparsers_service.add_parser('config',
                                                                    help='configure a service')
     parser_config_service.add_argument('action',
