@@ -58,6 +58,8 @@ def get_status(t):
 def is_lower_docker_version(current_image, comparison_version):
     _, version_main_number, image_name, tag = utils.parse_version_number(current_image)
     current_docker_version = tag[1:] if tag.startswith('v') else tag
+    if '-' in current_docker_version:
+        current_docker_version = current_docker_version.split('-')[0]
     if semver.match(current_docker_version, "<"+comparison_version):
         return True
 
@@ -297,6 +299,9 @@ def execute(args, auth):
                     sys.exit(1)
                 t = r.json()
                 if task[1] is None:
+                    if t["content"] is None:
+                        task[1] = False
+                        continue
                     content = json.loads(t["content"])
                     if "docker" not in content or not check_command(content["docker"]["command"]):
                         task[1] = False
