@@ -16,7 +16,7 @@ import client.launcher as launcher
 _reqcache = {}
 lookup_cache = {}
 test_storages = None
-CORPUS_SUFFIX = (".txt", ".tmx")
+CORPUS_SUFFIX = (".txt", ".tmx", ".json")
 
 launcher.LOGGER = logging.getLogger()
 
@@ -57,6 +57,11 @@ def group_list(url, auth):
 
 
 def get_group(url, auth, code):
+    return get_object_list('group', url, auth, code)
+
+
+def get_object_list(object_name, url, auth, code):
+    # object_name = group | role
     try:
         code_id = int(code)
         return True, code_id
@@ -72,13 +77,16 @@ def get_group(url, auth, code):
     elif len(codesplit) > 2:
         return False, "invalid code"
 
-    status_code, codes = group_list(url, auth)
+    if object_name == 'group':
+        status_code, codes = group_list(url, auth)
+    else:
+        status_code, codes = role_list(url, auth)
     if status_code != 200:
-        return False, "cannot get group list"
+        return False, f"cannot get {object_name} list"
     for c in codes:
         if c.get("entity_id") == entity_id and c["name"] == code:
             return True, c["id"]
-    return False, "unknown group"
+    return False, f"unknown {object_name}"
 
 
 def role_list(url, auth):
@@ -88,28 +96,7 @@ def role_list(url, auth):
 
 
 def get_role(url, auth, code):
-    try:
-        code_id = int(code)
-        return True, code_id
-    except Exception:
-        pass
-    codesplit = code.split(':')
-    entity_id = None
-    if len(codesplit) == 2:
-        status_code, entity_id = get_entity(url, auth, codesplit[0])
-        code = codesplit[1]
-        if not status_code:
-            return False, entity_id
-    elif len(codesplit) > 2:
-        return False, "invalid code"
-
-    status_code, codes = role_list(url, auth)
-    if status_code != 200:
-        return False, "cannot get role list"
-    for c in codes:
-        if c.get("entity_id") == entity_id and c["name"] == code:
-            return True, c["id"]
-    return False, "unknown role"
+    return get_object_list('role', url, auth, code)
 
 
 def user_list(url, auth):
@@ -238,12 +225,7 @@ def _lookup_repository(url, auth, service, remote_path, entity):
     if r.status_code != 200:
         return False, (r.status_code, result['message'])
 
-    lookup_cache[id] = []
-    for fileObj in result:
-        if fileObj.get('alias_names') and isinstance(fileObj['alias_names'], list):
-            lookup_cache[id].extend(fileObj['alias_names'])
-        elif fileObj.get('key'):
-            lookup_cache[id].append(fileObj['key'])
+    lookup_cache[id] = [fileObj['key'] for fileObj in result if fileObj.get('key')]
 
     return True, lookup_cache[id]
 
@@ -273,10 +255,13 @@ def _get_testfiles(url, auth, service, path, model, src_lang, tgt_lang):
                 sys.exit(1)
         else:
             count = 0
+            no_translate_dir = f"_{tgt_lang}{src_lang}_"
             for f in result:
                 if f.endswith("." + src_lang):
                     test_parts = f.split('/')
                     test_name = test_parts[len(test_parts) - 1]
+                    if no_translate_dir in test_name:
+                        continue
                     res.append(
                         ("%s:%s" % (storage_name, f), "pn9_testtrans:" +
                             model + "/" + storage_name + "/" + real_path + "/" + test_name + "." + tgt_lang))
@@ -284,9 +269,11 @@ def _get_testfiles(url, auth, service, path, model, src_lang, tgt_lang):
                 if f.endswith(CORPUS_SUFFIX):
                     test_parts = f.split('/')
                     test_name = test_parts[len(test_parts) - 1]
+                    if no_translate_dir in test_name:
+                        continue
                     res.append(
-                        ("%s:%s.%s" % (storage_name, f, src_lang), "pn9_testtrans:" +
-                         model + "/" + storage_name + "/" + real_path + "/" + test_name + "."+src_lang+'.' + tgt_lang))
+                        ("%s:%s.json" % (storage_name, f), "pn9_testtrans:" +
+                         model + "/" + storage_name + "/" + real_path + "/" + test_name + '.' + tgt_lang))
                     count += 1
             if entity == "CONF_DEFAULT":
                 entity = ""
@@ -306,8 +293,8 @@ def _get_outfiles(url, auth, service, path, model, src_lang, tgt_lang):
         real_path = path
     test_storages = _get_test_storages(url, auth, service)
     # Get test storage
-    output_paths = list(map(lambda t: model + "/" + t["name"] + "/" + real_path, test_storages))
-    output_paths.append(model + "/" + real_path)
+    output_paths = list(map(lambda t: os.path.join(model, t["name"], *real_path.split("/")), test_storages))
+    output_paths.append(os.path.join(model, *real_path.split("/")))
     # Get translated path
     for output_path in output_paths:
         status, result = _lookup_repository(url, auth, service, "%s:%s" % (storage, output_path), None)
@@ -344,10 +331,13 @@ def _get_multi_ref(reffile, result, storage):
 def _get_reffiles(url, auth, service, src_lang, tgt_lang, list_testfiles):
     res = []
     for (testfile, outfile) in list_testfiles:
-        if not testfile.endswith("." + src_lang):
+        if not testfile.endswith(("." + src_lang, '.json')):
             continue
         split = testfile.split(':')
         if len(split) >= 2:
+            if testfile.endswith('.json'):
+                res.append((outfile, testfile))
+                continue
             storage = split[0] + ':'
             testfile = ':'.join(split[1:])
             dirname = os.path.dirname(testfile)
@@ -390,7 +380,7 @@ def _get_datafiles(url, auth, service, path, lang):
 
 
 def tree_display(res, lvl, l, idx_result, model_maxsize, scorenames, bestscores, avg_scores,
-                 skip_noscores, has_noscores, show_owner, show_pruned, only_show_pruned, quiet=False):
+                 skip_noscores, has_noscores, show_owner, show_domain, show_pruned, only_show_pruned, quiet=False):
     sorted_l = sorted(l, key=lambda k: float(idx_result[k]["date"]))
     pref = ' ' * lvl
     for k in sorted_l:
@@ -440,6 +430,8 @@ def tree_display(res, lvl, l, idx_result, model_maxsize, scorenames, bestscores,
                     line_data.append(
                         owner_obj.get('entity_code') if owner_obj and isinstance(owner_obj, dict)
                         else owner_obj)
+                if show_domain:
+                    line_data.append(get_domain_from_model_info(item))
                 if show_pruned:
                     line_data.append(pruned)
                 if avg_scores:
@@ -447,7 +439,8 @@ def tree_display(res, lvl, l, idx_result, model_maxsize, scorenames, bestscores,
                     line_data.append(avg_score)
                 res.add_row(line_data + scorecols)
         tree_display(res, lvl + 1, item['children_models'], idx_result, model_maxsize, scorenames, bestscores,
-                     avg_scores, skip_noscores, has_noscores, show_owner, show_pruned, only_show_pruned, quiet)
+                     avg_scores, skip_noscores, has_noscores, show_owner, show_domain, show_pruned, only_show_pruned,
+                     quiet)
 
 
 # Calculate max depth of the trees
@@ -488,7 +481,7 @@ def _get_params(lparam, listcmd):
     idx = 0
     while idx < len(listcmd):
         if listcmd[idx] in lparam:
-            idx = idx + 1
+            idx += 1
             while idx < len(listcmd) and not listcmd[idx].startswith('-'):
                 res.append(listcmd[idx])
                 idx += 1
@@ -502,12 +495,12 @@ def _get_params_except_specified(lparam, listcmd):
     idx = 0
     while idx < len(listcmd):
         if listcmd[idx] in lparam:
-            idx = idx + 1
+            idx += 1
             while idx < len(listcmd) and not listcmd[idx].startswith('-'):
                 idx += 1
         else:
             res.append(listcmd[idx])
-            idx = idx + 1
+            idx += 1
             while idx < len(listcmd) and not listcmd[idx].startswith('-'):
                 res.append(listcmd[idx])
                 idx += 1
@@ -562,11 +555,15 @@ def check_upgrades(auth, url, upgrade, image, tag):
                                (image + ':' + tag_prefix + tag, r.text))
         if len(result) == 0:
             raise RuntimeError('unknown version %s' % (image + ':' + tag_prefix + tag))
-        versions = [version.parse(r['image']) for r in result]
+        versions = []
+        for item in result:
+            image_version = version.parse(item['image'].split(':')[-1])
+            if not image_version.is_prerelease:
+                versions.append(image_version)
         latest_version_parse = max(versions)
-        latest_version = latest_version_parse.base_version
+        latest_version = image + ':' + tag_prefix + latest_version_parse.base_version
         # selectively upgrade if later version available
-        if version.parse(image + ':' + tag_prefix + tag) < latest_version_parse:
+        if version.parse(tag) < latest_version_parse:
             if len(version_parts) < 3 or upgrade == "force":
                 # version incompletely qualified
                 launcher.LOGGER.info('automatically upgrading docker_image=%s to %s' %
@@ -587,7 +584,7 @@ def check_upgrades(auth, url, upgrade, image, tag):
                         break
                     else:
                         launcher.LOGGER.info('Please enter `y` or `n`.')
-        elif version.parse(image + ':' + tag_prefix + tag) == latest_version_parse:
+        elif version.parse(tag) == latest_version_parse:
             if len(version_parts) < 3:
                 # version incompletely qualified
                 launcher.LOGGER.info('automatically upgrading docker_image=%s to %s' %
@@ -669,3 +666,14 @@ def check_condition_to_get_model(options, model):
         return True
 
     return False
+
+
+def get_domain_from_model_info(model_info):
+    if model_info.get('domain'):
+        return model_info['domain']
+    if model_info.get('push') and isinstance(model_info['push'], list):
+        pushed_model_infos = [item for item in model_info['push'] if 'error' not in item]
+        if pushed_model_infos:
+            # get domain from the model's latest successful push information
+            return pushed_model_infos[-1].get('domain')
+    return None
