@@ -69,7 +69,8 @@ def find_files_parameters(v, files):
         if os.path.isdir(v):
             allfiles = [(os.path.join(v, f), os.path.join(global_basename, f))
                         for f in os.listdir(v) if os.path.isfile(os.path.join(v, f))]
-        allfiles = [(v, global_basename)]
+        else:
+            allfiles = [(v, global_basename)]
         for f in allfiles:
             files[f[1]] = (f[1], open(f[0], 'rb'))
             LOGGER.info('transferring local file: %s -> ${TMP_DIR}/%s', f[0], f[1])
@@ -222,6 +223,12 @@ parser_launch.add_argument('-c_train', '--cpus_train', type=int,
 parser_launch.add_argument('-c_trans', '--cpus_trans', type=int,
                            help='number of cpus for translation task - if not provided, '
                                 'will be obtained from pool config')
+parser_launch.add_argument('-g_trans', '--gpus_trans', type=int,
+                           help='number of gpus for translation task - if not provided, '
+                                'will be obtained from pool config')
+parser_launch.add_argument('-g_score', '--gpus_score', type=int,
+                           help='number of gpus for scoring task - if not provided, '
+                                'will be obtained from pool config')
 parser_launch.add_argument('-w', '--wait_after_launch', default=2, type=int,
                            help='if not 0, wait for this number of seconds after launch '
                                 'to check that launch is ok - by default wait for 2 seconds')
@@ -311,6 +318,10 @@ def _parse_local_filename(argument, files):
     else:
         return argument
 
+    if os.path.isdir(argument):
+        argument = find_files_parameters(argument, files)
+        return argument
+
     LOGGER.debug("considering %s is a file", argument)
 
     basename = os.path.basename(argument)
@@ -514,11 +525,14 @@ def process_request(s_list, cmd, subcmd, is_json, args, auth=None):
             content["priority"] = args.priority
         if args.dependency:
             content["dependency"] = args.dependency
+        auto_patch_envvar = 'true' if not args.not_patch_envvar else 'false'
 
         if cmd == "task" and subcmd == "launch":
             content["ncpus_prepr"] = args.cpus_prepr
             content["ncpus_train"] = args.cpus_train
             content["ncpus_trans"] = args.cpus_trans
+            content["ngpus_trans"] = args.gpus_trans
+            content["ngpus_score"] = args.gpus_score
 
             if args.iterations:
                 content["iterations"] = args.iterations
@@ -553,7 +567,7 @@ def process_request(s_list, cmd, subcmd, is_json, args, auth=None):
         LOGGER.debug("sending request: %s", json.dumps(content))
 
         launch_url = os.path.join(args.url, "task/launch", args.service)
-        data = {'content': json.dumps(content)}
+        data = {'content': json.dumps(content), 'auto_patch_envvar': auto_patch_envvar}
         if "entity_owner" in args:
             data['entity_owner'] = args.entity_owner
         r = requests.post(launch_url,
